@@ -1,4 +1,5 @@
 from zeno.api import distill, metric, model, transform, ZenoOptions
+from zeno.runner import zeno
 
 __all__ = [
     "model",
@@ -6,4 +7,5 @@ __all__ = [
     "metric",
     "transform",
     "ZenoOptions",
+    "zeno",
 ]
